@@ -709,7 +709,8 @@ void FolderModel::run(int row)
     // otherwise ask for security reasons. We also don't use the targetUrl()
     // from above since we don't want the resolved /home/foo/Desktop URL.
     run->setShowScriptExecutionPrompt(item.url().scheme() != QLatin1String("desktop")
-                                      || item.url().adjusted(QUrl::RemoveFilename).path() != QLatin1String("/"));
+                                      || item.url().adjusted(QUrl::RemoveFilename).path() != QLatin1String("/")
+                                      || !item.isDesktopFile());
 }
 
 void FolderModel::runSelected()
@@ -1597,13 +1598,9 @@ void FolderModel::createActions()
     refresh->setShortcut(QKeySequence(QKeySequence::Refresh));
     connect(refresh, &QAction::triggered, this, &FolderModel::refresh);
 
-    QAction *newDirAction = new QAction(QIcon::fromTheme(QStringLiteral("create_dir")), i18n("&Create Folder"), this);
-    m_actionCollection.setDefaultShortcut(newDirAction, KStandardShortcut::createFolder().last());
-    newDirAction->setVisible(false);
-    connect(newDirAction, &QAction::triggered, this, &FolderModel::createFolder);
-
     QAction *rename = KStandardAction::renameFile(this, &FolderModel::requestRename, this);
     QAction *trash = KStandardAction::moveToTrash(this, &FolderModel::moveSelectedToTrash, this);
+    QAction *del = KStandardAction::deleteFile(this, &FolderModel::deleteSelected, this);
     RemoveAction *remove = new RemoveAction(&m_actionCollection, this);
 
     QAction *emptyTrash = new QAction(QIcon::fromTheme(QStringLiteral("trash-empty")), i18n("&Empty Trash"), this);
@@ -1612,8 +1609,6 @@ void FolderModel::createActions()
     QAction *restoreFromTrash = new QAction(i18nc("Restore from trash", "Restore"), this);
     connect(restoreFromTrash, &QAction::triggered, this, &FolderModel::restoreSelectedFromTrash);
 
-    QAction *del = KStandardAction::deleteFile(this, &FolderModel::deleteSelected, this);
-
     QAction *actOpen = new QAction(QIcon::fromTheme(QStringLiteral("window-new")), i18n("&Open"), this);
     connect(actOpen, &QAction::triggered, this, &FolderModel::openSelected);
 
@@ -1630,7 +1625,6 @@ void FolderModel::createActions()
     m_actionCollection.addAction(QStringLiteral("del"), del);
     m_actionCollection.addAction(QStringLiteral("restoreFromTrash"), restoreFromTrash);
     m_actionCollection.addAction(QStringLiteral("emptyTrash"), emptyTrash);
-    m_actionCollection.addAction(QStringLiteral("create_dir"), newDirAction);
 
     // The RemoveAction needs to be updated after adding all actions to the actionCollection
     remove->update();
@@ -1809,20 +1803,20 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
         menu->addSeparator();
         menu->addAction(m_actionCollection.action(QStringLiteral("restoreFromTrash")));
 
-        KConfigGroup cg(KSharedConfig::openConfig(), "KDE");
-        bool showDeleteCommand = cg.readEntry("ShowDeleteCommand", false);
-
-        if (showDeleteCommand) {
+        if (isDeleteCommandShown()) {
             QAction *trashAction = m_actionCollection.action(QStringLiteral("trash"));
             QAction *deleteAction = m_actionCollection.action(QStringLiteral("del"));
-            deleteAction->setVisible(showDeleteCommand);
-            trashAction->setVisible(showDeleteCommand);
             menu->addAction(trashAction);
             menu->addAction(deleteAction);
         } else {
             if (RemoveAction *removeAction = qobject_cast<RemoveAction *>(m_actionCollection.action(QStringLiteral("remove")))) {
                 removeAction->update();
                 menu->addAction(removeAction);
+
+                // Used to monitor Shift modifier usage while the menu is open, to
+                // swap the Trash and Delete actions.
+                menu->installEventFilter(removeAction);
+                QCoreApplication::instance()->installEventFilter(removeAction);
             }
         }
 
@@ -1858,13 +1852,6 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
         menu->windowHandle()->setTransientParent(visualParent->window());
     }
 
-    // Used to monitor Shift modifier usage while the menu is open, to
-    // swap the Trash and Delete actions.
-    if (RemoveAction *removeAction = qobject_cast<RemoveAction *>(m_actionCollection.action(QStringLiteral("remove")))) {
-        menu->installEventFilter(removeAction);
-        QCoreApplication::instance()->installEventFilter(removeAction);
-    }
-
     menu->popup(m_menuPosition);
     connect(menu, &QMenu::aboutToHide, [menu]() {
         menu->deleteLater();
@@ -2013,8 +2000,16 @@ void FolderModel::moveSelectedToTrash()
         return;
     }
 
-    if (RemoveAction *action = qobject_cast<RemoveAction *>(m_actionCollection.action(QStringLiteral("remove")))) {
-        if (action->proxyAction() != m_actionCollection.action(QStringLiteral("trash"))) {
+    if (!isDeleteCommandShown()) {
+        if (RemoveAction *action = qobject_cast<RemoveAction *>(m_actionCollection.action(QStringLiteral("remove")))) {
+            if (action->proxyAction() != m_actionCollection.action(QStringLiteral("trash"))) {
+                return;
+            }
+        }
+    }
+
+    if (QAction *action = m_actionCollection.action(QStringLiteral("trash"))) {
+        if (!action->isEnabled()) {
             return;
         }
     }
@@ -2035,8 +2030,8 @@ void FolderModel::deleteSelected()
         return;
     }
 
-    if (RemoveAction *action = qobject_cast<RemoveAction *>(m_actionCollection.action(QStringLiteral("remove")))) {
-        if (action->proxyAction() != m_actionCollection.action(QStringLiteral("del"))) {
+    if (QAction *action = m_actionCollection.action(QStringLiteral("del"))) {
+        if (!action->isEnabled()) {
             return;
         }
     }
@@ -2113,3 +2108,9 @@ void FolderModel::createFolder()
     m_newMenu->setPopupFiles(QList<QUrl>() << m_dirModel->dirLister()->url());
     m_newMenu->createDirectory();
 }
+
+bool FolderModel::isDeleteCommandShown()
+{
+    KConfigGroup cg(KSharedConfig::openConfig(), "KDE");
+    return cg.readEntry("ShowDeleteCommand", false);
+}
