@@ -1,28 +1,13 @@
 /*
- * kcmmisc.cpp
- *
- * Copyright (c) 1997 Patrick Dowler dowler@morgul.fsh.uvic.ca
- *
- * Layout management, cleanups:
- * Copyright (c) 1999 Dirk A. Mueller <dmuell@gmx.net>
- *
- * Requires the Qt widget libraries, available at no cost at
- * https://www.qt.io/
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    kcmmisc.cpp
+
+    SPDX-FileCopyrightText: 1997 Patrick Dowler <dowler@morgul.fsh.uvic.ca>
+
+    Layout management, cleanups:
+    SPDX-FileCopyrightText: 1999 Dirk A. Mueller <dmuell@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kcmmisc.h"
 #include "ui_kcmmiscwidget.h"
